@@ -4,7 +4,7 @@
  *
  * Ported to KABC by Daniel Molkentin <molkentin@kde.org>
  *
- * SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -24,8 +24,7 @@
 #include <KConfigGroup>
 #include <KDirWatch>
 #include <KProtocolInfo>
-#include <kcoreaddons_version.h>
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <Kdelibs4ConfigMigrator>
 #endif
 
@@ -44,9 +43,7 @@ public:
     {
     }
 
-    ~LdapClientSearchPrivate()
-    {
-    }
+    ~LdapClientSearchPrivate() = default;
 
     void readWeighForClient(LdapClient *client, const KConfigGroup &config, int clientNumber);
     void readConfig();
@@ -90,7 +87,7 @@ LdapClientSearch::~LdapClientSearch() = default;
 
 void LdapClientSearch::LdapClientSearchPrivate::init(const QStringList &attributes)
 {
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Kdelibs4ConfigMigrator migrate(QStringLiteral("ldapsettings"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("kabldaprc"));
     migrate.migrate();
