@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -18,7 +18,6 @@
 #include <KMessageBox>
 #include <QDialogButtonBox>
 #include <QHBoxLayout>
-#include <kwidgetsaddons_version.h>
 
 #include "ldapclientsearch.h"
 #include "ldapclientsearchconfig.h"
@@ -110,20 +109,12 @@ void LdapConfigureWidget::slotRemoveHost()
         return;
     }
     auto ldapItem = dynamic_cast<LdapWidgetItem *>(item);
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     const int answer = KMessageBox::questionTwoActions(this,
-#else
-    const int answer = KMessageBox::questionYesNo(this,
-#endif
                                                        i18n("Do you want to remove setting for host \"%1\"?", ldapItem->server().host()),
                                                        i18n("Remove Host"),
                                                        KStandardGuiItem::remove(),
                                                        KStandardGuiItem::cancel());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     if (answer == KMessageBox::SecondaryAction) {
-#else
-    if (answer == KMessageBox::No) {
-#endif
         return;
     }
 
@@ -275,7 +266,7 @@ void LdapConfigureWidget::initGUI()
 {
     auto mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("layout"));
-    mainLayout->setContentsMargins(5, 5, 5, 5);
+    mainLayout->setContentsMargins(0, 0, 0, 0);
 
     // Contents of the QVGroupBox: label and hbox
     auto label = new QLabel(i18n("Check all servers that should be used:"));
